pub struct Sequencer { /* private fields */ }Expand description
Used by sender to track the message sequence numbers it sends to each destination. Each Sequencer object has a session id, sequence numbers are scoped by the (session_id, SeqKey) pair.
Implementations
Sourceimpl Sequencer
impl Sequencer
Sourcepub fn assign_seq(&self, port_id: &PortId) -> SeqInfo
pub fn assign_seq(&self, port_id: &PortId) -> SeqInfo
Assign the next seq for a port, mutate the sequencer with the new seq, and return the new seq.
- Actor ports: share the same sequence scheme per actor (keyed by ActorId)
- Non-actor ports: get individual sequence schemes (keyed by PortId)
Sourcepub fn session_id(&self) -> Uuid
pub fn session_id(&self) -> Uuid
Id of the session this sequencer belongs to.